.. ref-s2protocol

====================
s2protocol Reference
====================

s2_cli.py
---------

.. automodule:: s2protocol.s2_cli
   :members:
   :undoc-members:

decoders
--------

.. automodule:: s2protocol.decoders
   :members:
   :undoc-members:

versions
-------------

.. automodule:: s2protocol.versions
   :members:
   :undoc-members:

protocol49716
-------------

.. automodule:: s2protocol.versions.protocol49716
   :members:
   :undoc-members:

